pyAitu
======

.. image:: https://img.shields.io/pypi/v/pyAitu.svg?style=flat-square
    :target: https://pypi.org/project/pyAitu/
    :alt: Pypi package version

.. image:: https://img.shields.io/pypi/pyversions/pyAitu.svg?style=flat-square
    :target: https://pypi.org/project/pyAitu/
    :alt: Supported python version

.. image:: https://img.shields.io/readthedocs/pip/stable.svg?style=flat-square
    :target: https://pyaitu.readthedocs.io/en/latest/
    :alt: Documentation status

.. image:: https://img.shields.io/github/issues/btsdigital/pyAitu.svg?style=flat-square
    :target: https://github.com/btsdigital/pyAitu/issues
    :alt: Github issues

.. image:: https://img.shields.io/pypi/l/pyAitu.svg?style=flat-square
    :target: https://opensource.org/licenses/Apache-2.0
    :alt: Apache 2.0 License

**pyAitu** is a fully asynchronous framework for  `Aitu messenger <https://aitu.io>`_  Bot Api

Resources
---------

   - Pip: `pyAitu <https://pypi.org/project/pyAitu/>`_
   - Docs: `ReadTheDocs <https://pyaitu.readthedocs.io/en/latest/>`_
